*******************
ML Research Toolkit
*******************

|test| |codecov| |docs| |readthedocs| |pypi|

.. |test| image:: https://github.com/andriygav/MLResearchToolkit/workflows/test/badge.svg
    :target: https://github.com/andriygav/MLResearchToolkit/tree/master
    :alt: Test status
    
.. |codecov| image:: https://img.shields.io/codecov/c/github/andriygav/MLResearchToolkit/master
    :target: https://github.com/andriygav/MLResearchToolkit/tree/master
    :alt: Test coverage

.. |docs| image:: https://github.com/andriygav/MLResearchToolkit/workflows/docs/badge.svg
    :target: https://andriygav.github.io/MLResearchToolkit/
    :alt: Build status
    
.. |readthedocs| image:: https://img.shields.io/readthedocs/mlresearchtoolkit/latest?label=readthedocs
    :target: https://mlresearchtoolkit.readthedocs.io/en/latest/
    :alt: ReadTheDocs

.. |pypi| image:: https://img.shields.io/pypi/v/ml-research-toolkit
    :target: https://pypi.org/project/ml-research-toolkit/
    :alt: PyPI

Basic information
=================

This package provides some utilities for training machine learning models. In particular, it provides a package for sending messages to popular instant messengers. Secondly, it provides a package to automatically interact with datasets from the `UCI <https://archive.ics.uci.edu/ml/index.php>`_ repository.

Notifications
-------------

It provides a package for simple message sending to messengers during model training.

The following messengers are currently supported:
  - Telegram

Datasets
-------------

It provides a package for automatically interact with datasets.

The following datasets repository are currently supported:
  - `UCI <https://archive.ics.uci.edu/ml/index.php>`_.

Requirements and Installation
=============================
A simple instruction of installation using pip is provided near the `source code <https://github.com/andriygav/MLResearchToolkit/tree/master/src>`_.

More information about installation can be found in documentation `installation <https://andriygav.github.io/MLResearchToolkit/installation.html>`_ page.

Example of use
==============
A simple examples of module usage can be found in documentation `example <https://andriygav.github.io/MLResearchToolkit/example.html>`_ page.

